aboutsummaryrefslogtreecommitdiffstats
path: root/tools/test-common.sh
diff options
context:
space:
mode:
authorDario Lombardo <lomato@gmail.com>2018-11-12 10:44:32 +0100
committerAnders Broman <a.broman58@gmail.com>2018-11-12 12:36:26 +0000
commit51a2a00b7f717e1d1f16a2993e1b32b20ae3a17d (patch)
treed487522fb519abeb65fc0385f73bfb28f643e181 /tools/test-common.sh
parentb0e8abcf1e616124b215adafa7736e07b2f773fd (diff)
fix documentation and tests for cmake run directory.
Change-Id: If33a39c26714ebe699463d1c8c67469025767efb Reviewed-on: https://code.wireshark.org/review/30581 Petri-Dish: Dario Lombardo <lomato@gmail.com> Tested-by: Petri Dish Buildbot Reviewed-by: Anders Broman <a.broman58@gmail.com>
Diffstat (limited to 'tools/test-common.sh')
-rwxr-xr-xtools/test-common.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/tools/test-common.sh b/tools/test-common.sh
index 6195ca8795..902dce1820 100755
--- a/tools/test-common.sh
+++ b/tools/test-common.sh
@@ -19,9 +19,9 @@ fi
DATE=/bin/date
BASE_NAME=$TEST_TYPE-`$DATE +%Y-%m-%d`-$$
# Directory containing binaries. Default current directory.
if [ -z "$WIRESHARK_BIN_DIR" ]; then
- WIRESHARK_BIN_DIR=.
+ WIRESHARK_BIN_DIR=run
fi
# Temporary file directory and names.
@@ -19,9 +19,9 @@ fi
DATE=/bin/date
BASE_NAME=$TEST_TYPE-`$DATE +%Y-%m-%d`-$$
-# Directory containing binaries. Default current directory.
+# Directory containing binaries. Default: cmake run directory.
if [ -z "$WIRESHARK_BIN_DIR" ]; then